# This file has been autogenerated by the pywayland scanner

# Copyright © 2008-2013 Kristian Høgsberg
# Copyright © 2013      Rafael Antognolli
# Copyright © 2013      Jasper St. Pierre
# Copyright © 2010-2013 Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice (including the next
# paragraph) shall be included in all copies or substantial portions of the
# Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

from __future__ import annotations

import enum

from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)


class ZxdgPositionerV6(Interface):
    """Child surface positioner

    The :class:`~pywayland.protocol.xdg_shell.XdgPositioner` provides a
    collection of rules for the placement of a child surface relative to a
    parent surface. Rules can be defined to ensure the child surface remains
    within the visible area's borders, and to specify how the child surface
    changes its position, such as sliding along an axis, or flipping around a
    rectangle. These positioner-created rules are constrained by the
    requirement that a child surface must intersect with or be at least
    partially adjacent to its parent surface.

    See the various requests for details about possible rules.

    At the time of the request, the compositor makes a copy of the rules
    specified by the :class:`~pywayland.protocol.xdg_shell.XdgPositioner`.
    Thus, after the request is complete the
    :class:`~pywayland.protocol.xdg_shell.XdgPositioner` object can be
    destroyed or reused; further changes to the object will have no effect on
    previous usages.

    For an :class:`~pywayland.protocol.xdg_shell.XdgPositioner` object to be
    considered complete, it must have a non-zero size set by set_size, and a
    non-zero anchor rectangle set by set_anchor_rect. Passing an incomplete
    :class:`~pywayland.protocol.xdg_shell.XdgPositioner` object when
    positioning a surface raises an error.
    """

    name = "zxdg_positioner_v6"
    version = 1

    class error(enum.IntEnum):
        invalid_input = 0

    class anchor(enum.IntFlag):
        none = 0
        top = 1
        bottom = 2
        left = 4
        right = 8

    class gravity(enum.IntFlag):
        none = 0
        top = 1
        bottom = 2
        left = 4
        right = 8

    class constraint_adjustment(enum.IntFlag):
        none = 0
        slide_x = 1
        slide_y = 2
        flip_x = 4
        flip_y = 8
        resize_x = 16
        resize_y = 32


class ZxdgPositionerV6Proxy(Proxy[ZxdgPositionerV6]):
    interface = ZxdgPositionerV6

    @ZxdgPositionerV6.request()
    def destroy(self) -> None:
        """Destroy the :class:`~pywayland.protocol.xdg_shell.XdgPositioner` object

        Notify the compositor that the
        :class:`~pywayland.protocol.xdg_shell.XdgPositioner` will no longer be
        used.
        """
        self._marshal(0)
        self._destroy()

    @ZxdgPositionerV6.request(
        Argument(ArgumentType.Int),
        Argument(ArgumentType.Int),
    )
    def set_size(self, width: int, height: int) -> None:
        """Set the size of the to-be positioned rectangle

        Set the size of the surface that is to be positioned with the
        positioner object. The size is in surface-local coordinates and
        corresponds to the window geometry. See
        :func:`XdgSurface.set_window_geometry()
        <pywayland.protocol.xdg_shell.XdgSurface.set_window_geometry>`.

        If a zero or negative size is set the invalid_input error is raised.

        :param width:
            width of positioned rectangle
        :type width:
            `ArgumentType.Int`
        :param height:
            height of positioned rectangle
        :type height:
            `ArgumentType.Int`
        """
        self._marshal(1, width, height)

    @ZxdgPositionerV6.request(
        Argument(ArgumentType.Int),
        Argument(ArgumentType.Int),
        Argument(ArgumentType.Int),
        Argument(ArgumentType.Int),
    )
    def set_anchor_rect(self, x: int, y: int, width: int, height: int) -> None:
        """Set the anchor rectangle within the parent surface

        Specify the anchor rectangle within the parent surface that the child
        surface will be placed relative to. The rectangle is relative to the
        window geometry as defined by :func:`XdgSurface.set_window_geometry()
        <pywayland.protocol.xdg_shell.XdgSurface.set_window_geometry>` of the
        parent surface. The rectangle must be at least 1x1 large.

        When the :class:`~pywayland.protocol.xdg_shell.XdgPositioner` object is
        used to position a child surface, the anchor rectangle may not extend
        outside the window geometry of the positioned child's parent surface.

        If a zero or negative size is set the invalid_input error is raised.

        :param x:
            x position of anchor rectangle
        :type x:
            `ArgumentType.Int`
        :param y:
            y position of anchor rectangle
        :type y:
            `ArgumentType.Int`
        :param width:
            width of anchor rectangle
        :type width:
            `ArgumentType.Int`
        :param height:
            height of anchor rectangle
        :type height:
            `ArgumentType.Int`
        """
        self._marshal(2, x, y, width, height)

    @ZxdgPositionerV6.request(
        Argument(ArgumentType.Uint),
    )
    def set_anchor(self, anchor: int) -> None:
        """Set anchor rectangle anchor edges

        Defines a set of edges for the anchor rectangle. These are used to
        derive an anchor point that the child surface will be positioned
        relative to. If two orthogonal edges are specified (e.g. 'top' and
        'left'), then the anchor point will be the intersection of the edges
        (e.g. the top left position of the rectangle); otherwise, the derived
        anchor point will be centered on the specified edge, or in the center
        of the anchor rectangle if no edge is specified.

        If two parallel anchor edges are specified (e.g. 'left' and 'right'),
        the invalid_input error is raised.

        :param anchor:
            bit mask of anchor edges
        :type anchor:
            `ArgumentType.Uint`
        """
        self._marshal(3, anchor)

    @ZxdgPositionerV6.request(
        Argument(ArgumentType.Uint),
    )
    def set_gravity(self, gravity: int) -> None:
        """Set child surface gravity

        Defines in what direction a surface should be positioned, relative to
        the anchor point of the parent surface. If two orthogonal gravities are
        specified (e.g. 'bottom' and 'right'), then the child surface will be
        placed in the specified direction; otherwise, the child surface will be
        centered over the anchor point on any axis that had no gravity
        specified.

        If two parallel gravities are specified (e.g. 'left' and 'right'), the
        invalid_input error is raised.

        :param gravity:
            bit mask of gravity directions
        :type gravity:
            `ArgumentType.Uint`
        """
        self._marshal(4, gravity)

    @ZxdgPositionerV6.request(
        Argument(ArgumentType.Uint),
    )
    def set_constraint_adjustment(self, constraint_adjustment: int) -> None:
        """Set the adjustment to be done when constrained

        Specify how the window should be positioned if the originally intended
        position caused the surface to be constrained, meaning at least
        partially outside positioning boundaries set by the compositor. The
        adjustment is set by constructing a bitmask describing the adjustment
        to be made when the surface is constrained on that axis.

        If no bit for one axis is set, the compositor will assume that the
        child surface should not change its position on that axis when
        constrained.

        If more than one bit for one axis is set, the order of how adjustments
        are applied is specified in the corresponding adjustment descriptions.

        The default adjustment is none.

        :param constraint_adjustment:
            bit mask of constraint adjustments
        :type constraint_adjustment:
            `ArgumentType.Uint`
        """
        self._marshal(5, constraint_adjustment)

    @ZxdgPositionerV6.request(
        Argument(ArgumentType.Int),
        Argument(ArgumentType.Int),
    )
    def set_offset(self, x: int, y: int) -> None:
        """Set surface position offset

        Specify the surface position offset relative to the position of the
        anchor on the anchor rectangle and the anchor on the surface. For
        example if the anchor of the anchor rectangle is at (x, y), the surface
        has the gravity bottom|right, and the offset is (ox, oy), the
        calculated surface position will be (x + ox, y + oy). The offset
        position of the surface is the one used for constraint testing. See
        set_constraint_adjustment.

        An example use case is placing a popup menu on top of a user interface
        element, while aligning the user interface element of the parent
        surface with some user interface element placed somewhere in the popup
        surface.

        :param x:
            surface position x offset
        :type x:
            `ArgumentType.Int`
        :param y:
            surface position y offset
        :type y:
            `ArgumentType.Int`
        """
        self._marshal(6, x, y)


class ZxdgPositionerV6Resource(Resource):
    interface = ZxdgPositionerV6


class ZxdgPositionerV6Global(Global):
    interface = ZxdgPositionerV6


ZxdgPositionerV6._gen_c()
ZxdgPositionerV6.proxy_class = ZxdgPositionerV6Proxy
ZxdgPositionerV6.resource_class = ZxdgPositionerV6Resource
ZxdgPositionerV6.global_class = ZxdgPositionerV6Global



# This file has been autogenerated by the pywayland scanner

# Copyright © 2015 Martin Gräßlin
# Copyright © 2022 Simon Ser
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice (including the next
# paragraph) shall be included in all copies or substantial portions of the
# Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

from __future__ import annotations


from pywayland.protocol_core import Global, Interface, Proxy, Resource


class ExtIdleNotificationV1(Interface):
    """Idle notification

    This interface is used by the compositor to send idle notification events
    to clients.

    Initially the notification object is not idle. The notification object
    becomes idle when no user activity has happened for at least the timeout
    duration, starting from the creation of the notification object. User
    activity may include input events or a presence sensor, but is compositor-
    specific. If an idle inhibitor is active (e.g. another client has created a
    :class:`~pywayland.protocol.idle_inhibit_unstable_v1.ZwpIdleInhibitorV1` on
    a visible surface), the compositor must not make the notification object
    idle.

    When the notification object becomes idle, an idled event is sent. When
    user activity starts again, the notification object stops being idle, a
    resumed event is sent and the timeout is restarted.
    """

    name = "ext_idle_notification_v1"
    version = 1


class ExtIdleNotificationV1Proxy(Proxy[ExtIdleNotificationV1]):
    interface = ExtIdleNotificationV1

    @ExtIdleNotificationV1.request()
    def destroy(self) -> None:
        """Destroy the notification object

        Destroy the notification object.
        """
        self._marshal(0)
        self._destroy()


class ExtIdleNotificationV1Resource(Resource):
    interface = ExtIdleNotificationV1

    @ExtIdleNotificationV1.event()
    def idled(self) -> None:
        """Notification object is idle

        This event is sent when the notification object becomes idle.

        It's a compositor protocol error to send this event twice without a
        resumed event in-between.
        """
        self._post_event(0)

    @ExtIdleNotificationV1.event()
    def resumed(self) -> None:
        """Notification object is no longer idle

        This event is sent when the notification object stops being idle.

        It's a compositor protocol error to send this event twice without an
        idled event in-between. It's a compositor protocol error to send this
        event prior to any idled event.
        """
        self._post_event(1)


class ExtIdleNotificationV1Global(Global):
    interface = ExtIdleNotificationV1


ExtIdleNotificationV1._gen_c()
ExtIdleNotificationV1.proxy_class = ExtIdleNotificationV1Proxy
ExtIdleNotificationV1.resource_class = ExtIdleNotificationV1Resource
ExtIdleNotificationV1.global_class = ExtIdleNotificationV1Global



# This file has been autogenerated by the pywayland scanner

# Copyright © 2022 Joshua Ashton
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice (including the next
# paragraph) shall be included in all copies or substantial portions of the
# Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

from __future__ import annotations

import enum

from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)
from ..wayland import WlSurface
from .xwayland_surface_v1 import XwaylandSurfaceV1


class XwaylandShellV1(Interface):
    """Context object for xwayland shell

    :class:`XwaylandShellV1` is a singleton global object that provides the
    ability to create a
    :class:`~pywayland.protocol.xwayland_shell_v1.XwaylandSurfaceV1` object for
    a given :class:`~pywayland.protocol.wayland.WlSurface`.

    This interface is intended to be bound by the Xwayland server.

    A compositor must not allow clients other than Xwayland to bind to this
    interface. A compositor should hide this global from other clients'
    :class:`~pywayland.protocol.wayland.WlRegistry`. A client the compositor
    does not consider to be an Xwayland server attempting to bind this
    interface will result in an implementation-defined error.

    An Xwayland server that has bound this interface must not set the
    `WL_SURFACE_ID` atom on a window.
    """

    name = "xwayland_shell_v1"
    version = 1

    class error(enum.IntEnum):
        role = 0


class XwaylandShellV1Proxy(Proxy[XwaylandShellV1]):
    interface = XwaylandShellV1

    @XwaylandShellV1.request()
    def destroy(self) -> None:
        """Destroy the xwayland shell object

        Destroy the :class:`XwaylandShellV1` object.

        The child objects created via this interface are unaffected.
        """
        self._marshal(0)
        self._destroy()

    @XwaylandShellV1.request(
        Argument(ArgumentType.NewId, interface=XwaylandSurfaceV1),
        Argument(ArgumentType.Object, interface=WlSurface),
    )
    def get_xwayland_surface(self, surface: WlSurface) -> Proxy[XwaylandSurfaceV1]:
        """Assign the xwayland_surface surface role

        Create an
        :class:`~pywayland.protocol.xwayland_shell_v1.XwaylandSurfaceV1`
        interface for a given :class:`~pywayland.protocol.wayland.WlSurface`
        object and gives it the xwayland_surface role.

        It is illegal to create an
        :class:`~pywayland.protocol.xwayland_shell_v1.XwaylandSurfaceV1` for a
        :class:`~pywayland.protocol.wayland.WlSurface` which already has an
        assigned role and this will result in the `role` protocol error.

        See the documentation of
        :class:`~pywayland.protocol.xwayland_shell_v1.XwaylandSurfaceV1` for
        more details about what an
        :class:`~pywayland.protocol.xwayland_shell_v1.XwaylandSurfaceV1` is and
        how it is used.

        :param surface:
        :type surface:
            :class:`~pywayland.protocol.wayland.WlSurface`
        :returns:
            :class:`~pywayland.protocol.xwayland_shell_v1.XwaylandSurfaceV1`
        """
        id = self._marshal_constructor(1, XwaylandSurfaceV1, surface)
        return id


class XwaylandShellV1Resource(Resource):
    interface = XwaylandShellV1


class XwaylandShellV1Global(Global):
    interface = XwaylandShellV1


XwaylandShellV1._gen_c()
XwaylandShellV1.proxy_class = XwaylandShellV1Proxy
XwaylandShellV1.resource_class = XwaylandShellV1Resource
XwaylandShellV1.global_class = XwaylandShellV1Global



# This file has been autogenerated by the pywayland scanner

# Copyright © 2015 Martin Gräßlin
# Copyright © 2022 Simon Ser
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice (including the next
# paragraph) shall be included in all copies or substantial portions of the
# Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

from __future__ import annotations


from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)
from ..wayland import WlSeat
from .ext_idle_notification_v1 import ExtIdleNotificationV1


class ExtIdleNotifierV1(Interface):
    """Idle notification manager

    This interface allows clients to monitor user idle status.

    After binding to this global, clients can create
    :class:`~pywayland.protocol.ext_idle_notify_v1.ExtIdleNotificationV1`
    objects to get notified when the user is idle for a given amount of time.
    """

    name = "ext_idle_notifier_v1"
    version = 1


class ExtIdleNotifierV1Proxy(Proxy[ExtIdleNotifierV1]):
    interface = ExtIdleNotifierV1

    @ExtIdleNotifierV1.request()
    def destroy(self) -> None:
        """Destroy the manager

        Destroy the manager object. All objects created via this interface
        remain valid.
        """
        self._marshal(0)
        self._destroy()

    @ExtIdleNotifierV1.request(
        Argument(ArgumentType.NewId, interface=ExtIdleNotificationV1),
        Argument(ArgumentType.Uint),
        Argument(ArgumentType.Object, interface=WlSeat),
    )
    def get_idle_notification(self, timeout: int, seat: WlSeat) -> Proxy[ExtIdleNotificationV1]:
        """Create a notification object

        Create a new idle notification object.

        The notification object has a minimum timeout duration and is tied to a
        seat. The client will be notified if the seat is inactive for at least
        the provided timeout. See
        :class:`~pywayland.protocol.ext_idle_notify_v1.ExtIdleNotificationV1`
        for more details.

        A zero timeout is valid and means the client wants to be notified as
        soon as possible when the seat is inactive.

        :param timeout:
            minimum idle timeout in msec
        :type timeout:
            `ArgumentType.Uint`
        :param seat:
        :type seat:
            :class:`~pywayland.protocol.wayland.WlSeat`
        :returns:
            :class:`~pywayland.protocol.ext_idle_notify_v1.ExtIdleNotificationV1`
        """
        id = self._marshal_constructor(1, ExtIdleNotificationV1, timeout, seat)
        return id


class ExtIdleNotifierV1Resource(Resource):
    interface = ExtIdleNotifierV1


class ExtIdleNotifierV1Global(Global):
    interface = ExtIdleNotifierV1


ExtIdleNotifierV1._gen_c()
ExtIdleNotifierV1.proxy_class = ExtIdleNotifierV1Proxy
ExtIdleNotifierV1.resource_class = ExtIdleNotifierV1Resource
ExtIdleNotifierV1.global_class = ExtIdleNotifierV1Global



# This file has been autogenerated by the pywayland scanner

# Copyright 2021 Isaac Freund
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

from __future__ import annotations

import enum

from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)


class ExtSessionLockSurfaceV1(Interface):
    """A surface displayed while the session is locked

    The client may use lock surfaces to display a screensaver, render a dialog
    to enter a password and unlock the session, or however else it sees fit.

    On binding this interface the compositor will immediately send the first
    configure event. After making the ack_configure request in response to this
    event the client may attach and commit the first buffer. Committing the
    surface before acking the first configure is a protocol error. Committing
    the surface with a null buffer at any time is a protocol error.

    The compositor is free to handle keyboard/pointer focus for lock surfaces
    however it chooses. A reasonable way to do this would be to give the first
    lock surface created keyboard focus and change keyboard focus if the user
    clicks on other surfaces.
    """

    name = "ext_session_lock_surface_v1"
    version = 1

    class error(enum.IntEnum):
        commit_before_first_ack = 0
        null_buffer = 1
        dimensions_mismatch = 2
        invalid_serial = 3


class ExtSessionLockSurfaceV1Proxy(Proxy[ExtSessionLockSurfaceV1]):
    interface = ExtSessionLockSurfaceV1

    @ExtSessionLockSurfaceV1.request()
    def destroy(self) -> None:
        """Destroy the lock surface object

        This informs the compositor that the lock surface object will no longer
        be used.

        It is recommended for a lock client to destroy lock surfaces if their
        corresponding :class:`~pywayland.protocol.wayland.WlOutput` global is
        removed.

        If a lock surface on an active output is destroyed before the
        :func:`ExtSessionLockV1.unlock_and_destroy()
        <pywayland.protocol.ext_session_lock_v1.ExtSessionLockV1.unlock_and_destroy>`
        event is sent, the compositor must fall back to rendering a solid
        color.
        """
        self._marshal(0)
        self._destroy()

    @ExtSessionLockSurfaceV1.request(
        Argument(ArgumentType.Uint),
    )
    def ack_configure(self, serial: int) -> None:
        """Ack a configure event

        When a configure event is received, if a client commits the surface in
        response to the configure event, then the client must make an
        ack_configure request sometime before the commit request, passing along
        the serial of the configure event.

        If the client receives multiple configure events before it can respond
        to one, it only has to ack the last configure event.

        A client is not required to commit immediately after sending an
        ack_configure request - it may even ack_configure several times before
        its next surface commit.

        A client may send multiple ack_configure requests before committing,
        but only the last request sent before a commit indicates which
        configure event the client really is responding to.

        Sending an ack_configure request consumes the configure event
        referenced by the given serial, as well as all older configure events
        sent on this object.

        It is a protocol error to issue multiple ack_configure requests
        referencing the same configure event or to issue an ack_configure
        request referencing a configure event older than the last configure
        event acked for a given lock surface.

        :param serial:
            serial from the configure event
        :type serial:
            `ArgumentType.Uint`
        """
        self._marshal(1, serial)


class ExtSessionLockSurfaceV1Resource(Resource):
    interface = ExtSessionLockSurfaceV1

    @ExtSessionLockSurfaceV1.event(
        Argument(ArgumentType.Uint),
        Argument(ArgumentType.Uint),
        Argument(ArgumentType.Uint),
    )
    def configure(self, serial: int, width: int, height: int) -> None:
        """The client should resize its surface

        This event is sent once on binding the interface and may be sent again
        at the compositor's discretion, for example if output geometry changes.

        The width and height are in surface-local coordinates and are exact
        requirements. Failing to match these surface dimensions in the next
        commit after acking a configure is a protocol error.

        :param serial:
            serial for use in ack_configure
        :type serial:
            `ArgumentType.Uint`
        :param width:
        :type width:
            `ArgumentType.Uint`
        :param height:
        :type height:
            `ArgumentType.Uint`
        """
        self._post_event(0, serial, width, height)


class ExtSessionLockSurfaceV1Global(Global):
    interface = ExtSessionLockSurfaceV1


ExtSessionLockSurfaceV1._gen_c()
ExtSessionLockSurfaceV1.proxy_class = ExtSessionLockSurfaceV1Proxy
ExtSessionLockSurfaceV1.resource_class = ExtSessionLockSurfaceV1Resource
ExtSessionLockSurfaceV1.global_class = ExtSessionLockSurfaceV1Global



# This file has been autogenerated by the pywayland scanner

# Copyright 2021 Isaac Freund
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

from __future__ import annotations

import enum

from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)
from ..wayland import WlOutput
from ..wayland import WlSurface
from .ext_session_lock_surface_v1 import ExtSessionLockSurfaceV1


class ExtSessionLockV1(Interface):
    """Manage lock state and create lock surfaces

    On creation of this object either the locked or finished event will
    immediately be sent.

    The locked event indicates that the session is locked. This means that the
    compositor should stop rendering and providing input to normal clients.
    Instead the compositor should blank all outputs with an opaque color such
    that their normal content is fully hidden.

    The only surfaces that should be rendered while the session is locked are
    the lock surfaces created through this interface and optionally, at the
    compositor's discretion, special privileged surfaces such as input methods
    or portions of desktop shell UIs.

    If the client dies while the session is locked, the compositor should not
    unlock the session in response. It is acceptable for the session to be
    permanently locked if this happens. The compositor may choose to continue
    to display the lock surfaces the client had mapped before it died or
    alternatively fall back to a solid color, this is compositor policy.

    Compositors may also allow a secure way to recover the session, the details
    of this are compositor policy. Compositors may allow a new client to create
    a :class:`ExtSessionLockV1` object and take responsibility for unlocking
    the session, they may even start a new lock client instance automatically.
    """

    name = "ext_session_lock_v1"
    version = 1

    class error(enum.IntEnum):
        invalid_destroy = 0
        invalid_unlock = 1
        role = 2
        duplicate_output = 3
        already_constructed = 4


class ExtSessionLockV1Proxy(Proxy[ExtSessionLockV1]):
    interface = ExtSessionLockV1

    @ExtSessionLockV1.request()
    def destroy(self) -> None:
        """Destroy the session lock

        This informs the compositor that the lock object will no longer be
        used. Existing objects created through this interface remain valid.

        After this request is made, lock surfaces created through this object
        should be destroyed by the client as they will no longer be used by the
        compositor.

        It is a protocol error to make this request if the locked event was
        sent, the unlock_and_destroy request must be used instead.
        """
        self._marshal(0)
        self._destroy()

    @ExtSessionLockV1.request(
        Argument(ArgumentType.NewId, interface=ExtSessionLockSurfaceV1),
        Argument(ArgumentType.Object, interface=WlSurface),
        Argument(ArgumentType.Object, interface=WlOutput),
    )
    def get_lock_surface(self, surface: WlSurface, output: WlOutput) -> Proxy[ExtSessionLockSurfaceV1]:
        """Create a lock surface for a given output

        The client is expected to create lock surfaces for all outputs
        currently present and any new outputs as they are advertised. These
        won't be displayed by the compositor unless the lock is successful and
        the locked event is sent.

        Providing a :class:`~pywayland.protocol.wayland.WlSurface` which
        already has a role or already has a buffer attached or committed is a
        protocol error, as is attaching/committing a buffer before the first
        :func:`ExtSessionLockSurfaceV1.configure()
        <pywayland.protocol.ext_session_lock_v1.ExtSessionLockSurfaceV1.configure>`
        event.

        Attempting to create more than one lock surface for a given output is a
        duplicate_output protocol error.

        :param surface:
        :type surface:
            :class:`~pywayland.protocol.wayland.WlSurface`
        :param output:
        :type output:
            :class:`~pywayland.protocol.wayland.WlOutput`
        :returns:
            :class:`~pywayland.protocol.ext_session_lock_v1.ExtSessionLockSurfaceV1`
        """
        id = self._marshal_constructor(1, ExtSessionLockSurfaceV1, surface, output)
        return id

    @ExtSessionLockV1.request()
    def unlock_and_destroy(self) -> None:
        """Unlock the session, destroying the object

        This request indicates that the session should be unlocked, for example
        because the user has entered their password and it has been verified by
        the client.

        This request also informs the compositor that the lock object will no
        longer be used and may be safely destroyed. Existing objects created
        through this interface remain valid.

        After this request is made, lock surfaces created through this object
        should be destroyed by the client as they will no longer be used by the
        compositor.

        It is a protocol error to make this request if the locked event has not
        been sent. In that case, the lock object may only be destroyed using
        the destroy request.

        Note that a correct client that wishes to exit directly after unlocking
        the session must use the :func:`WlDisplay.sync()
        <pywayland.protocol.wayland.WlDisplay.sync>` request to ensure the
        server receives and processes the unlock_and_destroy request. Otherwise
        there is no guarantee that the server has unlocked the session due to
        the asynchronous nature of the Wayland protocol. For example, the
        server might terminate the client with a protocol error before it
        processes the unlock_and_destroy request.
        """
        self._marshal(2)
        self._destroy()


class ExtSessionLockV1Resource(Resource):
    interface = ExtSessionLockV1

    @ExtSessionLockV1.event()
    def locked(self) -> None:
        """Session successfully locked

        This client is now responsible for displaying graphics while the
        session is locked and deciding when to unlock the session.

        Either this event or the finished event will be sent immediately on
        creation of this object.

        If this event is sent, making the destroy request is a protocol error,
        the lock object may only be destroyed using the unlock_and_destroy
        request.
        """
        self._post_event(0)

    @ExtSessionLockV1.event()
    def finished(self) -> None:
        """The session lock object should be destroyed

        The compositor has decided that the session lock should be destroyed.
        Exactly when this event is sent is compositor policy, but it will never
        be sent more than once for a given session lock object.

        This might be sent because there is already another
        :class:`ExtSessionLockV1` object held by a client, or the compositor
        has decided to deny the request to lock the session for some other
        reason. This might also be sent because the compositor implements some
        alternative, secure way to authenticate and unlock the session.

        Either this event or the locked event will be sent exactly once on
        creation of this object. If the locked event is sent on creation of
        this object, the finished event may still be sent at some later time in
        this object's lifetime, this is compositor policy.

        Upon receiving this event, the client should make either the destroy
        request or the unlock_and_destroy request, depending on whether or not
        the locked event was received on this object.
        """
        self._post_event(1)


class ExtSessionLockV1Global(Global):
    interface = ExtSessionLockV1


ExtSessionLockV1._gen_c()
ExtSessionLockV1.proxy_class = ExtSessionLockV1Proxy
ExtSessionLockV1.resource_class = ExtSessionLockV1Resource
ExtSessionLockV1.global_class = ExtSessionLockV1Global



# This file has been autogenerated by the pywayland scanner

# Copyright 2021 Isaac Freund
#
# Permission to use, copy, modify, and/or distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

from __future__ import annotations


from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)
from .ext_session_lock_v1 import ExtSessionLockV1


class ExtSessionLockManagerV1(Interface):
    """Used to lock the session

    This interface is used to request that the session be locked.
    """

    name = "ext_session_lock_manager_v1"
    version = 1


class ExtSessionLockManagerV1Proxy(Proxy[ExtSessionLockManagerV1]):
    interface = ExtSessionLockManagerV1

    @ExtSessionLockManagerV1.request()
    def destroy(self) -> None:
        """Destroy the session lock manager object

        This informs the compositor that the session lock manager object will
        no longer be used. Existing objects created through this interface
        remain valid.
        """
        self._marshal(0)
        self._destroy()

    @ExtSessionLockManagerV1.request(
        Argument(ArgumentType.NewId, interface=ExtSessionLockV1),
    )
    def lock(self) -> Proxy[ExtSessionLockV1]:
        """Attempt to lock the session

        This request creates a session lock and asks the compositor to lock the
        session. The compositor will send either the
        :func:`ExtSessionLockV1.locked()
        <pywayland.protocol.ext_session_lock_v1.ExtSessionLockV1.locked>` or
        :func:`ExtSessionLockV1.finished()
        <pywayland.protocol.ext_session_lock_v1.ExtSessionLockV1.finished>`
        event on the created object in response to this request.

        :returns:
            :class:`~pywayland.protocol.ext_session_lock_v1.ExtSessionLockV1`
        """
        id = self._marshal_constructor(1, ExtSessionLockV1)
        return id


class ExtSessionLockManagerV1Resource(Resource):
    interface = ExtSessionLockManagerV1


class ExtSessionLockManagerV1Global(Global):
    interface = ExtSessionLockManagerV1


ExtSessionLockManagerV1._gen_c()
ExtSessionLockManagerV1.proxy_class = ExtSessionLockManagerV1Proxy
ExtSessionLockManagerV1.resource_class = ExtSessionLockManagerV1Resource
ExtSessionLockManagerV1.global_class = ExtSessionLockManagerV1Global



# This file has been autogenerated by the pywayland scanner

# Copyright © 2022 Kenny Levinsen
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice (including the next
# paragraph) shall be included in all copies or substantial portions of the
# Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

from __future__ import annotations


from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)


class WpFractionalScaleV1(Interface):
    """Fractional scale interface to a :class:`~pywayland.protocol.wayland.WlSurface`

    An additional interface to a :class:`~pywayland.protocol.wayland.WlSurface`
    object which allows the compositor to inform the client of the preferred
    scale.
    """

    name = "wp_fractional_scale_v1"
    version = 1


class WpFractionalScaleV1Proxy(Proxy[WpFractionalScaleV1]):
    interface = WpFractionalScaleV1

    @WpFractionalScaleV1.request()
    def destroy(self) -> None:
        """Remove surface scale information for surface

        Destroy the fractional scale object. When this object is destroyed,
        preferred_scale events will no longer be sent.
        """
        self._marshal(0)
        self._destroy()


class WpFractionalScaleV1Resource(Resource):
    interface = WpFractionalScaleV1

    @WpFractionalScaleV1.event(
        Argument(ArgumentType.Uint),
    )
    def preferred_scale(self, scale: int) -> None:
        """Notify of new preferred scale

        Notification of a new preferred scale for this surface that the
        compositor suggests that the client should use.

        The sent scale is the numerator of a fraction with a denominator of
        120.

        :param scale:
            the new preferred scale
        :type scale:
            `ArgumentType.Uint`
        """
        self._post_event(0, scale)


class WpFractionalScaleV1Global(Global):
    interface = WpFractionalScaleV1


WpFractionalScaleV1._gen_c()
WpFractionalScaleV1.proxy_class = WpFractionalScaleV1Proxy
WpFractionalScaleV1.resource_class = WpFractionalScaleV1Resource
WpFractionalScaleV1.global_class = WpFractionalScaleV1Global



# This file has been autogenerated by the pywayland scanner

# Copyright © 2021 Emmanuel Gil Peyrot
# Copyright © 2022 Xaver Hugl
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice (including the next
# paragraph) shall be included in all copies or substantial portions of the
# Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

from __future__ import annotations

import enum

from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)
from ..wayland import WlSurface
from .wp_content_type_v1 import WpContentTypeV1


class WpContentTypeManagerV1(Interface):
    """Surface content type manager

    This interface allows a client to describe the kind of content a surface
    will display, to allow the compositor to optimize its behavior for it.

    Warning! The protocol described in this file is currently in the testing
    phase. Backward compatible changes may be added together with the
    corresponding interface version bump. Backward incompatible changes can
    only be done by creating a new major version of the extension.
    """

    name = "wp_content_type_manager_v1"
    version = 1

    class error(enum.IntEnum):
        already_constructed = 0


class WpContentTypeManagerV1Proxy(Proxy[WpContentTypeManagerV1]):
    interface = WpContentTypeManagerV1

    @WpContentTypeManagerV1.request()
    def destroy(self) -> None:
        """Destroy the content type manager object

        Destroy the content type manager. This doesn't destroy objects created
        with the manager.
        """
        self._marshal(0)
        self._destroy()

    @WpContentTypeManagerV1.request(
        Argument(ArgumentType.NewId, interface=WpContentTypeV1),
        Argument(ArgumentType.Object, interface=WlSurface),
    )
    def get_surface_content_type(self, surface: WlSurface) -> Proxy[WpContentTypeV1]:
        """Create a new toplevel decoration object

        Create a new content type object associated with the given surface.

        Creating a :class:`~pywayland.protocol.content_type_v1.WpContentTypeV1`
        from a :class:`~pywayland.protocol.wayland.WlSurface` which already has
        one attached is a client error: already_constructed.

        :param surface:
        :type surface:
            :class:`~pywayland.protocol.wayland.WlSurface`
        :returns:
            :class:`~pywayland.protocol.content_type_v1.WpContentTypeV1`
        """
        id = self._marshal_constructor(1, WpContentTypeV1, surface)
        return id


class WpContentTypeManagerV1Resource(Resource):
    interface = WpContentTypeManagerV1


class WpContentTypeManagerV1Global(Global):
    interface = WpContentTypeManagerV1


WpContentTypeManagerV1._gen_c()
WpContentTypeManagerV1.proxy_class = WpContentTypeManagerV1Proxy
WpContentTypeManagerV1.resource_class = WpContentTypeManagerV1Resource
WpContentTypeManagerV1.global_class = WpContentTypeManagerV1Global



# This file has been autogenerated by the pywayland scanner

# Copyright © 2021 Xaver Hugl
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice (including the next
# paragraph) shall be included in all copies or substantial portions of the
# Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

from __future__ import annotations

import enum

from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)


class WpTearingControlV1(Interface):
    """Per-surface tearing control interface

    An additional interface to a :class:`~pywayland.protocol.wayland.WlSurface`
    object, which allows the client to hint to the compositor if the content on
    the surface is suitable for presentation with tearing. The default
    presentation hint is vsync. See presentation_hint for more details.
    """

    name = "wp_tearing_control_v1"
    version = 1

    class presentation_hint(enum.IntEnum):
        vsync = 0
        async_ = 1


class WpTearingControlV1Proxy(Proxy[WpTearingControlV1]):
    interface = WpTearingControlV1

    @WpTearingControlV1.request(
        Argument(ArgumentType.Uint),
    )
    def set_presentation_hint(self, hint: int) -> None:
        """Set presentation hint

        Set the presentation hint for the associated
        :class:`~pywayland.protocol.wayland.WlSurface`. This state is double-
        buffered and is applied on the next :func:`WlSurface.commit()
        <pywayland.protocol.wayland.WlSurface.commit>`.

        The compositor is free to dynamically respect or ignore this hint based
        on various conditions like hardware capabilities, surface state and
        user preferences.

        :param hint:
        :type hint:
            `ArgumentType.Uint`
        """
        self._marshal(0, hint)

    @WpTearingControlV1.request()
    def destroy(self) -> None:
        """Destroy tearing control object

        Destroy this surface tearing object and revert the presentation hint to
        vsync. The change will be applied on the next :func:`WlSurface.commit()
        <pywayland.protocol.wayland.WlSurface.commit>`.
        """
        self._marshal(1)
        self._destroy()


class WpTearingControlV1Resource(Resource):
    interface = WpTearingControlV1


class WpTearingControlV1Global(Global):
    interface = WpTearingControlV1


WpTearingControlV1._gen_c()
WpTearingControlV1.proxy_class = WpTearingControlV1Proxy
WpTearingControlV1.resource_class = WpTearingControlV1Resource
WpTearingControlV1.global_class = WpTearingControlV1Global



# This file has been autogenerated by the pywayland scanner

# Copyright 2014 © Stephen "Lyude" Chandler Paul
# Copyright 2015-2016 © Red Hat, Inc.
#
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice (including the
# next paragraph) shall be included in all copies or substantial
# portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT.  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from __future__ import annotations


from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)
from .zwp_tablet_pad_v2 import ZwpTabletPadV2
from .zwp_tablet_tool_v2 import ZwpTabletToolV2
from .zwp_tablet_v2 import ZwpTabletV2


class ZwpTabletSeatV2(Interface):
    """Controller object for graphic tablet devices of a seat

    An object that provides access to the graphics tablets available on this
    seat. After binding to this interface, the compositor sends a set of
    wp_tablet_seat.tablet_added and wp_tablet_seat.tool_added events.
    """

    name = "zwp_tablet_seat_v2"
    version = 1


class ZwpTabletSeatV2Proxy(Proxy[ZwpTabletSeatV2]):
    interface = ZwpTabletSeatV2

    @ZwpTabletSeatV2.request()
    def destroy(self) -> None:
        """Release the memory for the tablet seat object

        Destroy the wp_tablet_seat object. Objects created from this object are
        unaffected and should be destroyed separately.
        """
        self._marshal(0)
        self._destroy()


class ZwpTabletSeatV2Resource(Resource):
    interface = ZwpTabletSeatV2

    @ZwpTabletSeatV2.event(
        Argument(ArgumentType.NewId, interface=ZwpTabletV2),
    )
    def tablet_added(self, id: ZwpTabletV2) -> None:
        """New device notification

        This event is sent whenever a new tablet becomes available on this
        seat. This event only provides the object id of the tablet, any static
        information about the tablet (device name, vid/pid, etc.) is sent
        through the wp_tablet interface.

        :param id:
            the newly added graphics tablet
        :type id:
            :class:`~pywayland.protocol.tablet_unstable_v2.ZwpTabletV2`
        """
        self._post_event(0, id)

    @ZwpTabletSeatV2.event(
        Argument(ArgumentType.NewId, interface=ZwpTabletToolV2),
    )
    def tool_added(self, id: ZwpTabletToolV2) -> None:
        """A new tool has been used with a tablet

        This event is sent whenever a tool that has not previously been used
        with a tablet comes into use. This event only provides the object id of
        the tool; any static information about the tool (capabilities, type,
        etc.) is sent through the wp_tablet_tool interface.

        :param id:
            the newly added tablet tool
        :type id:
            :class:`~pywayland.protocol.tablet_unstable_v2.ZwpTabletToolV2`
        """
        self._post_event(1, id)

    @ZwpTabletSeatV2.event(
        Argument(ArgumentType.NewId, interface=ZwpTabletPadV2),
    )
    def pad_added(self, id: ZwpTabletPadV2) -> None:
        """New pad notification

        This event is sent whenever a new pad is known to the system.
        Typically, pads are physically attached to tablets and a pad_added
        event is sent immediately after the wp_tablet_seat.tablet_added.
        However, some standalone pad devices logically attach to tablets at
        runtime, and the client must wait for wp_tablet_pad.enter to know the
        tablet a pad is attached to.

        This event only provides the object id of the pad. All further features
        (buttons, strips, rings) are sent through the wp_tablet_pad interface.

        :param id:
            the newly added pad
        :type id:
            :class:`~pywayland.protocol.tablet_unstable_v2.ZwpTabletPadV2`
        """
        self._post_event(2, id)


class ZwpTabletSeatV2Global(Global):
    interface = ZwpTabletSeatV2


ZwpTabletSeatV2._gen_c()
ZwpTabletSeatV2.proxy_class = ZwpTabletSeatV2Proxy
ZwpTabletSeatV2.resource_class = ZwpTabletSeatV2Resource
ZwpTabletSeatV2.global_class = ZwpTabletSeatV2Global



# This file has been autogenerated by the pywayland scanner

# Copyright © 2022 Joshua Ashton
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice (including the next
# paragraph) shall be included in all copies or substantial portions of the
# Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

from __future__ import annotations

import enum

from pywayland.protocol_core import (
    Argument,
    ArgumentType,
    Global,
    Interface,
    Proxy,
    Resource,
)


class XwaylandSurfaceV1(Interface):
    """Interface for associating xwayland windows to wl_surfaces

    An Xwayland surface is a surface managed by an Xwayland server. It is used
    for associating surfaces to Xwayland windows.

    The Xwayland server associated with actions in this interface is determined
    by the Wayland client making the request.

    The client must call :func:`WlSurface.commit()
    <pywayland.protocol.wayland.WlSurface.commit>` on the corresponding
    :class:`~pywayland.protocol.wayland.WlSurface` for the
    :class:`XwaylandSurfaceV1` state to take effect.
    """

    name = "xwayland_surface_v1"
    version = 1

    class error(enum.IntEnum):
        already_associated = 0
        invalid_serial = 1


class XwaylandSurfaceV1Proxy(Proxy[XwaylandSurfaceV1]):
    interface = XwaylandSurfaceV1

    @XwaylandSurfaceV1.request(
        Argument(ArgumentType.Uint),
        Argument(ArgumentType.Uint),
    )
    def set_serial(self, serial_lo: int, serial_hi: int) -> None:
        """Associates a xwayland window to a :class:`~pywayland.protocol.wayland.WlSurface`

        Associates an Xwayland window to a
        :class:`~pywayland.protocol.wayland.WlSurface`. The association state
        is double-buffered and will be applied at the time
        :func:`WlSurface.commit()
        <pywayland.protocol.wayland.WlSurface.commit>` of the corresponding
        :class:`~pywayland.protocol.wayland.WlSurface` is called.

        The `serial_lo` and `serial_hi` parameters specify a non-zero monotonic
        serial number which is entirely unique and provided by the Xwayland
        server equal to the serial value provided by a client message with a
        message type of the `WL_SURFACE_SERIAL` atom on the X11 window for this
        surface to be associated to.

        The serial value in the `WL_SURFACE_SERIAL` client message is specified
        as having the lo-bits specified in `l[0]` and the hi-bits specified in
        `l[1]`.

        If the serial value provided by `serial_lo` and `serial_hi` is not
        valid, the `invalid_serial` protocol error will be raised.

        An X11 window may be associated with multiple surfaces throughout its
        lifespan. (eg. unmapping and remapping a window).

        For each :class:`~pywayland.protocol.wayland.WlSurface`, this state
        must not be committed more than once, otherwise the
        `already_associated` protocol error will be raised.

        :param serial_lo:
            The lower 32-bits of the serial number associated with the X11
            window
        :type serial_lo:
            `ArgumentType.Uint`
        :param serial_hi:
            The upper 32-bits of the serial number associated with the X11
            window
        :type serial_hi:
            `ArgumentType.Uint`
        """
        self._marshal(0, serial_lo, serial_hi)

    @XwaylandSurfaceV1.request()
    def destroy(self) -> None:
        """Destroy the xwayland surface object

        Destroy the :class:`XwaylandSurfaceV1` object.

        Any already existing associations are unaffected by this action.
        """
        self._marshal(1)
        self._destroy()


class XwaylandSurfaceV1Resource(Resource):
    interface = XwaylandSurfaceV1


class XwaylandSurfaceV1Global(Global):
    interface = XwaylandSurfaceV1


XwaylandSurfaceV1._gen_c()
XwaylandSurfaceV1.proxy_class = XwaylandSurfaceV1Proxy
XwaylandSurfaceV1.resource_class = XwaylandSurfaceV1Resource
XwaylandSurfaceV1.global_class = XwaylandSurfaceV1Global



# Copyright 2015 Sean Vig
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .version import __version__  # noqa: F401

try:
    from ._ffi import ffi, lib  # noqa: F401
except ImportError:
    raise ImportError(
        "No module named pywayland._ffi, be sure to run `python ./pywayland/ffi_build.py`"
    )

__wayland_version__ = "{}.{}.{}".format(
    lib.WAYLAND_VERSION_MAJOR, lib.WAYLAND_VERSION_MINOR, lib.WAYLAND_VERSION_MICRO
)
